==> qt-creator-opensource-src-4.1.0.zip: qt-creator-opensource-src-4.1.0/src/plugins/autotest/qtest/qttestframework.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "../itestframework.h"

namespace Autotest {
namespace Internal {

class QtTestFramework : public ITestFramework
{
public:
    QtTestFramework() : ITestFramework(true) {}
    const char *name() const override;
    unsigned priority() const override;

protected:
    ITestParser *createTestParser() const override;
    TestTreeItem *createRootNode() const override;
};

} // namespace Internal
} // namespace Autotest

==> qt-creator-opensource-src-4.8.2.zip: qt-creator-opensource-src-4.8.2/src/plugins/autotest/qtest/qttestframework.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "../itestframework.h"

namespace Autotest {
namespace Internal {

class QtTestFramework : public ITestFramework
{
public:
    QtTestFramework() : ITestFramework(true) {}
    const char *name() const override;
    unsigned priority() const override;
    IFrameworkSettings *createFrameworkSettings() const override;
    ITestSettingsPage *createSettingsPage(QSharedPointer<IFrameworkSettings> settings) const override;
    bool hasFrameworkSettings() const override;

protected:
    ITestParser *createTestParser() const override;
    TestTreeItem *createRootNode() const override;
};

} // namespace Internal
} // namespace Autotest
